# -*- coding:utf-8; tab-width:4; mode:python -*-
'''
mail related subjects and assertions
'''

from commodity.type_ import checked_type
from commodity.os_ import SubProcess
from commodity.str_ import Printable

from .assertion import Matcher


class SMTP(Printable):
    pass
